Home - Climate CoLab
Description: Collaborate with people all over the world to win contests on what to do about climate change.
Keywords: climate change, contest, global warming, MIT, sustainability, energy, efficiency, renewable energy, industry, cement, hydraulic fracturing, fracking, diesel, fossil fuel, waste management, cities, resiliency, consumption, adaptation, transportation, buildings, agriculture, forestry, geoengineering

Facebook Google
OR
Forgot your password?

#### Oh Snap!

Unfortunately your request caused an error. To help us improve our service we would kindly ask you to provide a short description of the steps you took prior to receiving this message.

If you provide your e-Mail address below we will let you know as soon as we've fixed the problem

Submit

# Web Content Display Web Content Display

# In the Climate CoLab, you can
work with people from all over the world to create proposals for what to do about climate change.

Learn More Get Involved
The Climate CoLab is a project of the
MIT Center for Collective Intelligence
in collaboration with many other organizations

| Climate CoLab Winners

# MIT Contests (ICE)

## Vote now! see all contests

### Global Climate Action Plan 2015

What should be the world’s plan to address climate change?
5 proposals
380 votes

# MIT Contests (ICE)

## Featured contests see all contests

### Harnessing the power of MIT alumni

What is the most effective thing that MIT alumni can do to help implement the MIT Plan for Action on Climate Change?
58 proposals
44 comments

### Materials Matter

Fabrics and textiles impact our climate -- a lot. How can we spark a materials revolution by rethinking how we value and use them?
6 proposals
15 comments

### Fostering Climate Collaboration in Boulder, CO 2016

How can we build community engagement and connectivity around climate change?
8 proposals
14 comments

### Designing High Density Urban Bike Parking

Is there a design solution that provides high-density, accessible, cost-effective bicycle parking in the urban context?
4 proposals
8 comments

# Web Content Display Web Content Display

## Top News

Dec 2. News from COP21: United Nations & Climate CoLab collaborate on resilience contests
Dec 1. Climate CoLab at COP21
Nov 30. The Climate CoLab exceeds 50,000 members!
Nov 16. Voting now open!
Nov 15. Climate CoLab seeks skilled web developer
Oct 6. New contests open
More...

See news features on Boston Globe, ClimateWire, Weather Channel, PRI's The World, ClimateWire, Grist, Discovery News, Popular Science, Guardian, and PBS NOVA.

# Feeds Portlet

Download activities in CSV format

## CoLab Activities

### 32 minutes ago

XinHere joined ClimateColab community

### 31 minutes ago

XinHere voted for Proposal Let's play the...

### 30 minutes ago

XinHere is supporting Proposal Let's play t...
View all activities

# Web Content Display Web Content Display

## Twitter Activity

Facebook Twitter Reddit Pinterest Linkedin Youtube
Tweets by @ClimateCoLab

#### Please log in to the Climate CoLab

Welcome! To access the link you clicked, please login or register as a free member using Facebook, Google, or your username & password.

Facebook Google
Username:
Password:
Forgot your password?
Haven't registered yet?
LOGIN

#### Password recovery

Enter your email or screen name to get new password

Username/email:
Request new password